@@ -1,16 +1,9 @@
-from __future__ import division
-# Copyright (c) 2010-2022 openpyxl
+
+# Copyright (c) 2010-2023 openpyxl
 
 import math
 
-from openpyxl.compat import deprecated
-
-from openpyxl.styles.colors import Color, BLACK, WHITE
-from openpyxl.utils.units import (
-    pixels_to_EMU,
-    EMU_to_pixels,
-    short_color,
-)
+from openpyxl.utils.units import pixels_to_EMU
 
 
 class Drawing(object):
@@ -41,6 +34,7 @@ class Drawing(object):
     def width(self):
         return self._width
 
+
     @width.setter
     def width(self, w):
         if self.resize_proportional and w:
@@ -48,10 +42,12 @@ class Drawing(object):
             self._height = round(ratio * w)
         self._width = w
 
+
     @property
     def height(self):
         return self._height
 
+
     @height.setter
     def height(self, h):
         if self.resize_proportional and h:
@@ -59,6 +55,7 @@ class Drawing(object):
             self._width = round(ratio * h)
         self._height = h
 
+
     def set_dimension(self, w=0, h=0):
 
         xratio = w / self._width
@@ -72,13 +69,6 @@ class Drawing(object):
                 self._width = math.ceil(yratio * self._width)
                 self._height = h
 
-    @deprecated("Private method used when serialising")
-    def get_emu_dimensions(self):
-        """ return (x, y, w, h) in EMU """
-
-        return (pixels_to_EMU(self.left), pixels_to_EMU(self.top),
-            pixels_to_EMU(self._width), pixels_to_EMU(self._height))
-
 
     @property
     def anchor(self):
